@@ -202,7 +202,7 @@ def ToList(input):
 _USED_DIRS = set()
 
 def _PyScript(env, target, source, command = "python $SOURCES", capture=None,
-        execute=None, tempdir=None, exit=False, lightweight=True, *args, **kwargs): 
+        execute=None, tempdir=None, exit=False, clean=True, lightweight=True, *args, **kwargs): 
     """
     A new Builder added to a scons environment which has the same syntax as Command.
     """
@@ -226,10 +226,11 @@ def _PyScript(env, target, source, command = "python $SOURCES", capture=None,
     elif capture == "both": command[-1] += " > ${TARGETS[0]} 2> ${TARGETS[1]}"
     elif capture == None: pass
 
-    command_sig = [ env.subst(c, target=target, source=subst) for c in command ] 
+    command_sig = [ env.subst(c, target=target, source=subst) for c in command ]
 
-    basename = None
-    if (execute or exit) and tempdir == None:
+    if exit and "exit" in ARGUMENTS: execute = "exit %s #" % (ARGUMENTS["exit"])
+
+    if tempdir == None:
         m = hashlib.sha1()
         m.update("\n".join(command_sig))
         basename = os.path.join("temp", "." + base64.b64encode(m.digest(), "+="), '')
@@ -237,7 +238,7 @@ def _PyScript(env, target, source, command = "python $SOURCES", capture=None,
 
     if env.GetOption("clean") and basename:
         if os.path.exists(basename): env.Execute(Delete(basename))
-    elif basename:
+    elif execute:
         if not os.path.exists(basename): mkdir_p(basename)
         scons = os.path.join(basename, "SConscript")
         file = open(scons, 'w')
@@ -253,7 +254,7 @@ command =  [env.subst(c, target=stargets, source=sources) for c in %s ]
 command += ["mv %%s %%s" %% (s, t) for s,t in zip(stargets, targets)]
 
 gen = lambda source, target, env, for_signature: command_sig if for_signature else command
-PyScript(targets, sources, CommandGeneratorAction(gen,{}))
+PyScript(targets, sources, CommandGeneratorAction(gen,{}), clean=False)
 """ % (repr(command_sig), repr(command))
         file.close()
 
@@ -279,13 +280,14 @@ PyScript(targets, sources, CommandGeneratorAction(gen,{}))
 
         if not lightweight: command = exe + " -Q"
 
-    if execute: command = execute + " " + basename
-    if exit and "exit" in ARGUMENTS: command = "exit %s # %s" % (ARGUMENTS["exit"], basename)
+    if execute: command = [execute + " " + basename]
 
     ftargets = [t + ".force" for t in target]
     if reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
         command = ["mv %s %s" %(f,t) for f,t in zip(ftargets,target)]
 
+    if clean and not execute and os.path.exists(basename): env.Execute("rm -rf %s" % basename)
+
     gen = lambda source, target, env, for_signature: command_sig if for_signature else command
     return env.Command(target, source, CommandGeneratorAction(gen,{}), *args, **kwargs)
 
@@ -339,7 +341,7 @@ def _PyScons(env, target, source, scons, execute=None, options="-Q",
     if not execute: cmd = [cmd, cleancmd] if clean else [cmd]
     else: cmd = [execute + " " + basename]
 
-    if exit and "exit" in ARGUMENTS: command = "exit %s # %s" % (ARGUMENTS["exit"], basename)
+    if exit and "exit" in ARGUMENTS: cmd = "exit %s # %s" % (ARGUMENTS["exit"], basename)
 
     ftargets = [t + ".force" for t in target]
     if reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
